from django.db import models

from utils.model import BaseModel, SingleChoiceField


class Agent(BaseModel):
    name = models.CharField(max_length=64, blank=True, null=True, verbose_name="资产名称")
    ip = models.GenericIPAddressField(blank=True, null=True, verbose_name="ip地址")
    port = models.SmallIntegerField(default=22, verbose_name='端口号')
    username = models.CharField(max_length=32, blank=True, null=True, verbose_name="用户名")
    password = models.CharField(max_length=32, blank=True, null=True, verbose_name="密码")

    class Meta:
        db_table = 'asset_agent'
        verbose_name = '资产表'
        verbose_name_plural = verbose_name


class Repo(BaseModel):
    name = models.CharField(max_length=64, blank=True, null=True, verbose_name="repo名称")
    content = models.TextField(blank=True, null=True, verbose_name='repo详情')

    class Meta:
        db_table = 'asset_repo'
        verbose_name = 'repo表'
        verbose_name_plural = verbose_name


class Task(BaseModel):
    name = models.CharField(max_length=64, blank=True, null=True, verbose_name="任务名称")
    plan = SingleChoiceField(max_length=2, scope='migration_plan', default='A', verbose_name='迁移方案')

    # ** 迁移方案A status **
    # 0未开始
    # 1检查账号完成
    # 2检查方德源完成
    # 3RPM检查完成
    # 4abi检测完成
    # 5迁移完成
    # ** 迁移方案B status **
    # 0未开始
    # 6检查账号完成
    # 7检查迁移文件完成
    # 8迁移完成
    status = SingleChoiceField(max_length=4, scope='task_status', default=0, verbose_name='任务状态')
    repo = models.ForeignKey("Repo", blank=True, null=True, related_name='tasks', on_delete=models.CASCADE,
                             db_constraint=False, verbose_name='repo')
    path_gz = models.CharField(max_length=128, blank=True, null=True, verbose_name="迁移方案B文件路径")

    class Meta:
        db_table = 'asset_task'
        verbose_name = '任务表'
        verbose_name_plural = verbose_name


class TaskAgent(BaseModel):
    task = models.ForeignKey("Task", blank=True, null=True, related_name='taskagents', on_delete=models.CASCADE,
                             db_constraint=False, verbose_name='关联任务')
    agent = models.ForeignKey("Agent", blank=True, null=True, related_name='taskagents', on_delete=models.CASCADE,
                              db_constraint=False, verbose_name='关联agent')

    # ** 迁移方案A status **
    # 0未开始
    # 1检查账号中        10检查账号成功        100检查账号失败
    # 2检查方德源中      20检查方德源完成       200检查方德源失败
    # 3RPM兼容性检测     30RPM兼容性检测完成    300RPM兼容性检测失败
    # 4abi检测中        40abi检测完成         400abi检测失败
    # 5迁移中           50迁移完成            500迁移失败
    # ** 迁移方案B status **
    # 0未开始
    # 6检查账号中     60检查账号成功    600检查账号失败
    # 7检查迁移文件中 70检查迁移文件完成 700检查迁移文件失败
    # 8迁移中        80迁移完成        800迁移失败
    status = SingleChoiceField(max_length=4, scope='taskagent_status', default=0, verbose_name='子任务状态')
    msg = models.CharField(max_length=512, blank=True, null=True, verbose_name="状态信息")

    class Meta:
        db_table = 'asset_taskagent'
        verbose_name = '任务agent表'
        verbose_name_plural = verbose_name


class TaskAgentData(BaseModel):
    task_agent = models.OneToOneField("TaskAgent", blank=True, null=True, related_name='taskagentdata',
                                   on_delete=models.CASCADE, db_constraint=False, verbose_name='关联任务taskagent')
    info_old = models.TextField(blank=True, null=True, verbose_name='原系统info')
    info_new = models.TextField(blank=True, null=True, verbose_name='迁移后info')
    rpm_old = models.TextField(blank=True, null=True, verbose_name='原系统rpm包')
    rpm_new = models.TextField(blank=True, null=True, verbose_name='迁移后rpm包')
    config_old = models.TextField(blank=True, null=True, verbose_name='原系统config')
    config_new = models.TextField(blank=True, null=True, verbose_name='迁移后config')

    class Meta:
        db_table = 'asset_taskagent_data'
        verbose_name = '任务agent数据表'
        verbose_name_plural = verbose_name
