from asset.models import Agent, Repo, Task, TaskAgent, TaskAgentData
from asset.serializers import AgentSerializer, RepoSerializer, TaskSerializer, TaskAgentSerializer
from utils.response import SuccessResponse
from utils.viewset import BaseModelViewSet


class AgentViewSet(BaseModelViewSet):
    queryset = Agent.objects.all()
    serializer_class = AgentSerializer
    route_label = '资产模块'
    filterset_fields = {"name": ["icontains"]}


class RepoViewSet(BaseModelViewSet):
    queryset = Repo.objects.all()
    serializer_class = RepoSerializer
    route_label = 'repo模块'
    filterset_fields = {"name": ["icontains"], "content": ["icontains"]}


class TaskViewSet(BaseModelViewSet):
    queryset = Task.objects.all().order_by("-create_time")
    serializer_class = TaskSerializer
    route_label = '任务模块'
    filterset_fields = {"name": ["icontains"], "status": ["exact"], "plan": ["exact"]}

    def create(self, request, *args, **kwargs):
        """
        参数agent_ids: ["xxx", "xxx"]
        """
        serializer = self.get_serializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        self.perform_create(serializer)
        agent_ids = request.data.get('agent_ids')
        if agent_ids:
            taskagents = []
            taskagentdatas = []
            for agent_id in agent_ids:
                taskagent = TaskAgent(task_id=serializer.data.get('id'), agent_id=agent_id)
                taskagents.append(taskagent)
                taskagentdata = TaskAgentData(task_agent_id=taskagent.id)
                taskagentdatas.append(taskagentdata)
            TaskAgent.objects.bulk_create(taskagents)
            TaskAgentData.objects.bulk_create(taskagentdatas)
        return SuccessResponse(serializer.data)

    def destroy(self, request, *args, **kwargs):
        instance = self.get_object()
        TaskAgent.objects.filter(task_id=instance.id).delete()
        TaskAgentData.objects.filter(task_agent__task_id=instance.id).delete()
        return super().destroy(request, *args, **kwargs)


class TaskAgentViewSet(BaseModelViewSet):
    queryset = TaskAgent.objects.all()
    serializer_class = TaskAgentSerializer
    route_label = '任务详情模块'
    filterset_fields = {"task": ["exact"], "status": ["exact"], "task_id": ["exact"]}
