from rest_framework.decorators import action

from asset.models import TaskAgent, Agent
from thread_queue import run_migrate_a, run_migrate_b
from utils.response import SuccessResponse
from utils.util import RemoteExec, log_path
from utils.viewset import BaseViewSet


class MigrateViewSet(BaseViewSet):
    route_label = '迁移模块'
    route_method = {'action_a_by_task': '运行迁移方案A', 'get_log_a_by_taskagent': '获取迁移方案A日志',
                    'action_b_by_task': '运行迁移方案B', 'get_log_b_by_taskagent': '获取迁移方案B日志'}

    @action(methods=['get'], detail=False)
    def action_a_by_task(self, request):
        """
        通过task_id批量迁移agent,异步执行,参数 action_a_by_task/?task_id=xxx
        """
        task_id = request.query_params.get('task_id')
        taskagents = TaskAgent.objects.filter(task__id=task_id)
        if all([int(taskagent.status) in [5, 50, 500] for taskagent in taskagents]):
            return SuccessResponse(msg='任务执行中或已经完成')
        for taskagent in taskagents:
            run_migrate_a(taskagent)
        return SuccessResponse()

    @action(methods=['get'], detail=False)
    def get_log_a_by_taskagent(self, request):
        """
        通过taskagent_id和行号获取日志,参数 get_log_a_by_taskagent/?taskagent_id=xxx&nu=1
        """
        nu = int(request.query_params.get('nu'))
        taskagent_id = request.query_params.get('taskagent_id')
        agent = Agent.objects.filter(taskagents__id=taskagent_id).first()
        if agent is None:
            raise Exception("taskagent_id不存在")
        remote = (agent.ip, agent.port, agent.username, agent.password)
        content, nu = get_log(remote, nu)
        data = {"content": content, "nu": nu}
        return SuccessResponse(data)

    @action(methods=['get'], detail=False)
    def action_b_by_task(self, request):
        """
        通过task_id批量迁移agent,异步执行,参数 action_b_by_task/?task_id=xxx
        """
        task_id = request.query_params.get('task_id')
        taskagents = TaskAgent.objects.filter(task__id=task_id)
        if all([int(taskagent.status) in [8, 80, 800] for taskagent in taskagents]):
            return SuccessResponse(msg='任务执行中或已经完成')
        for taskagent in taskagents:
            run_migrate_b(taskagent)
        return SuccessResponse()

    @action(methods=['get'], detail=False)
    def get_log_b_by_taskagent(self, request):
        """
        通过taskagent_id和行号获取日志,参数 get_log_b_by_taskagent/?taskagent_id=xxx&nu=1
        """
        nu = int(request.query_params.get('nu'))
        taskagent_id = request.query_params.get('taskagent_id')
        agent = Agent.objects.filter(taskagents__id=taskagent_id).first()
        if agent is None:
            raise Exception("taskagent_id不存在")
        remote = (agent.ip, agent.port, agent.username, agent.password)
        content, nu = get_log(remote, nu)
        data = {"content": content, "nu": nu}
        return SuccessResponse(data)


def get_log(remote, nu):
    try:
        ip, port, username, password = remote
        with RemoteExec(ip=ip, port=port, username=username, password=password) as ssh:
            content = ssh.exec(f'tail -n +{nu} {log_path}')
            c = content.count('\n')
            if c > 9999:
                nu += 10000
                content = '\n'.join(content.splitlines()[:10000])
            else:
                nu += c
                if content:
                    nu += 1
        return content, nu
    except:
        return '', nu
