import base64
import logging
import os
import traceback

from migrate_check_ext import get_centos_version
from utils.util import MigrateRemoteExec

logger = logging.getLogger()


def action_migrate(remote, repo_content, taskagent=None):
    """
    迁移agent
    """
    ip, port, username, password = remote
    is_success, msg = True, '成功'
    is_minimal = False
    centos_version = get_centos_version(remote)
    with MigrateRemoteExec(ip=ip, port=port, username=username, password=password) as ssh:
        if ssh.exec('grep -Rn "@^minimal" /root/anaconda-ks.cfg'):
            is_minimal = True
        if centos_version in ['7.0', '7.1']:
            is_minimal = True
            if ssh.exec('grep -Rn "@gnome-desktop" /root/anaconda-ks.cfg'):
                is_minimal = False
    repo_content = base64.b64encode(repo_content.encode('utf-8')).decode('utf-8')
    repo_content = repo_content.replace('=', '_')
    try:
        # 支持的版本从7.0到8.5之间
        if is_minimal is True and centos_version == '7.0':
            #migrate_py, func_name = 'migrate_a_char.py', 'main70'
            migrate_py, func_name = 'migrate_a_char2char.py', 'main70'
        elif is_minimal is True and centos_version in ['7.1', '7.2', '7.3', '7.4', '7.5']:
            #migrate_py, func_name = 'migrate_a_char.py', 'main71_75'
            migrate_py, func_name = 'migrate_a_char2char.py', 'main71_75'
        elif is_minimal is True and centos_version == '7.6':
            #migrate_py, func_name = 'migrate_a_char.py', 'main76'
            migrate_py, func_name = 'migrate_a_char2char.py', 'main76'
        elif is_minimal is True and centos_version in ['7.7', '7.8', '7.9']:
            #migrate_py, func_name = 'migrate_a_char.py', 'main77_79'
            migrate_py, func_name = 'migrate_a_char2char.py', 'main77_79'
        elif is_minimal is True and centos_version in ['8.0', '8.1', '8.2', '8.3', '8.4', '8.5']:
            #migrate_py, func_name = 'migrate_a_char.py', 'main80_85'
            migrate_py, func_name = 'migrate_a_char2char.py', 'main80_85'

        elif is_minimal is False and centos_version == '7.0':
            migrate_py, func_name = 'migrate_a_gnome.py', 'main70'
        elif is_minimal is False and centos_version == '7.1':
            migrate_py, func_name = 'migrate_a_gnome.py', 'main71'
        elif is_minimal is False and centos_version in ['7.2', '7.3', '7.4', '7.5', '7.6']:
            migrate_py, func_name = 'migrate_a_gnome.py', 'main72_76'
        elif is_minimal is False and centos_version in ['7.7', '7.8', '7.9']:
            migrate_py, func_name = 'migrate_a_gnome.py', 'main77_79'
        elif is_minimal is False and centos_version in ['8.0', '8.1', '8.2', '8.3', '8.4', '8.5']:
            migrate_py, func_name = 'migrate_a_gnome.py', 'main80_85'
        else:
            raise Exception('暂不支持该迁移')
        command = f'./fab -f {migrate_py} -H {ip} --port {port} -u {username} -p {password} {func_name}:{repo_content}'
        logger.info('迁移命令执行：' + command)
        os.system(command)
        logger.info('迁移命令成功：' + command)
    except Exception as e:
        traceback.print_exc()
        exc_str = traceback.format_exc()
        is_success, msg = False, str(e)
    return is_success, msg, taskagent

# remote = ("60.10.11.194", 22, "root", "1")
# repo_content = """[BaseOS]
# name=BaseOS
# baseurl=http://60.10.11.199/nfs4/
# enabled=1
# gpgcheck=0
#
# [updates]
# name=NFS-4.0 - Updates
# baseurl=http://40.40.10.201/nfs4/updates/
# enabled=1
# gpgcheck=0
# """
# print(action_migrate(remote, repo_content))
