import base64
import os
import uuid

from fabric.api import *
from fabric.sftp import SFTP
import logging
import time

# env.user = 'root'
# env.hosts = ['60.10.11.231']
# env.password = '1'
env.warn_only = True

# repo_content="""[BaseOS]
# name=BaseOS
# baseurl=http://40.40.10.201/nfs4-yxy/
# enabled=1
# gpgcheck=0
# priority=1
# """

config_content = """
# This file controls the state of SELinux on the system.
# SELINUX= can take one of these three values:
#     enforcing - SELinux security policy is enforced.
#     permissive - SELinux prints warnings instead of enforcing.
#     disabled - No SELinux policy is loaded.
SELINUX=disabled
# SELINUXTYPE= can take one of these three values:
#     targeted - Targeted processes are protected,
#     minimum - Modification of targeted policy. Only selected processes are protected. 
#     mls - Multi Level Security protection.
SELINUXTYPE=targeted



"""
config_realtek_driver = """
[Unit]
Description=Load Realtek drivers.
Before=network-online.target
 
[Service]
Type=simple
ExecStartPre=/usr/sbin/rmmod r8169
ExecStart=/usr/sbin/modprobe r8169
 
[Install]
WantedBy=multi-user.target

"""

local_seconfig_file_path = '/root/config'
realtek_driver_file_path = '/root/load-realtek-driver.service'
ssh_repo_file_path = '/etc/yum.repos.d/'
log_path = '/migrate.log'

# 配置日志输出到文件
logging.basicConfig(filename='fabric.log', filemode='w', level=logging.INFO)


def upload_file(lpath, remote_path):
    # 使用Connection对象连接到远程服务器
    put(lpath, remote_path, use_sudo=True, mirror_local_mode=True, mode=0o644, temp_dir="/tmp")


def run_command(command):
    command = command.strip()
    content = "echo" + " \"执行:[" + time.strftime(
        "%H:%M:%S") + "] ==================== " + command + " ====================\" >> " + log_path
    run(content)
    if any([command.endswith(" &"), command.endswith(" 2>&1")]):  # 有一个为true都pass
        pass
    else:
        command = command + " >> " + log_path + " 2>&1"
    run(command)


def groupinstall_gnome():
    # 安装groupinstall gnome
    run_command('yum install -y	NetworkManager-libreswan-gnome	')
    run_command('yum install -y	PackageKit-command-not-found	')
    run_command('yum install -y	PackageKit-gtk3-module	')
    run_command('yum install -y	abrt-desktop	')
    run_command('yum install -y	at-spi2-atk	')
    run_command('yum install -y	at-spi2-core	')
    run_command('yum install -y	avahi	')
    run_command('yum install -y	baobab	')
    run_command('yum install -y	cheese	')
    run_command('yum install -y	compat-cheese314	')
    run_command('yum install -y	control-center	')
    run_command('yum install -y	dconf	')
    run_command('yum install -y	empathy	')
    run_command('yum install -y	eog	')
    run_command('yum install -y	evince	')
    run_command('yum install -y	evince-nautilus	')
    run_command('yum install -y	file-roller	')
    run_command('yum install -y	file-roller-nautilus	')
    run_command('yum install -y	firewall-config	')
    run_command('yum install -y	firstboot	')
    run_command('yum install -y	fprintd-pam	')
    run_command('yum install -y	gdm	')
    run_command('yum install -y	gedit	')
    run_command('yum install -y	gnome-bluetooth	')
    run_command('yum install -y	gnome-calculator	')
    run_command('yum install -y	gnome-clocks	')
    run_command('yum install -y	gnome-color-manager	')
    run_command('yum install -y	gnome-contacts	')
    run_command('yum install -y	gnome-dictionary	')
    run_command('yum install -y	gnome-disk-utility	')
    run_command('yum install -y	gnome-font-viewer	')
    run_command('yum install -y	gnome-getting-started-docs	')
    run_command('yum install -y	gnome-icon-theme	')
    run_command('yum install -y	gnome-icon-theme-extras	')
    run_command('yum install -y	gnome-icon-theme-symbolic	')
    run_command('yum install -y	gnome-packagekit	')
    run_command('yum install -y	gnome-packagekit-updater	')
    run_command('yum install -y	gnome-screenshot	')
    run_command('yum install -y	gnome-session	')
    run_command('yum install -y	gnome-session-xsession	')
    run_command('yum install -y	gnome-settings-daemon	')
    run_command('yum install -y	gnome-shell	')
    run_command('yum install -y	gnome-shell-extension-apps-menu	')
    run_command('yum install -y	gnome-shell-extension-common	')
    run_command('yum install -y	gnome-shell-extension-dash-to-panel	')
    run_command('yum install -y	gnome-shell-extension-drive-menu	')
    run_command('yum install -y	gnome-shell-extension-top-icons	')
    run_command('yum install -y	gnome-software	')
    run_command('yum install -y	gnome-system-log	')
    run_command('yum install -y	gnome-system-monitor	')
    run_command('yum install -y	gnome-terminal	')
    run_command('yum install -y	gnome-terminal-nautilus	')
    run_command('yum install -y	gnome-themes-standard	')
    run_command('yum install -y	gnome-tweak-tool	')
    run_command('yum install -y	gnome-user-docs	')
    run_command('yum install -y	gnome-weather	')
    run_command('yum install -y	gstreamer1-libav	')
    run_command('yum install -y	gucharmap	')
    run_command('yum install -y	gvfs-afc	')
    run_command('yum install -y	gvfs-afp	')
    run_command('yum install -y	gvfs-archive	')
    run_command('yum install -y	gvfs-fuse	')
    run_command('yum install -y	gvfs-goa	')
    run_command('yum install -y	gvfs-gphoto2	')
    run_command('yum install -y	gvfs-mtp	')
    run_command('yum install -y	gvfs-smb	')
    run_command('yum install -y	libcanberra-gtk2	')
    run_command('yum install -y	libcanberra-gtk3	')
    run_command('yum install -y	libproxy-mozjs	')
    run_command('yum install -y	librsvg2	')
    run_command('yum install -y	libsane-hpaio	')
    run_command('yum install -y	metacity	')
    run_command('yum install -y	mousetweaks	')
    run_command('yum install -y	nautilus	')
    run_command('yum install -y	nautilus-sendto	')
    run_command('yum install -y	nm-connection-editor	')
    run_command('yum install -y	orca	')
    run_command('yum install -y	qgnomeplatform	')
    run_command('yum install -y	sane-backends-drivers-scanners	')
    run_command('yum install -y	seahorse	')
    run_command('yum install -y	setroubleshoot	')
    run_command('yum install -y	sushi	')
    run_command('yum install -y	totem	')
    run_command('yum install -y	totem-nautilus	')
    run_command('yum install -y	vinagre	')
    run_command('yum install -y	vino	')
    run_command('yum install -y	xdg-desktop-portal-gtk	')
    run_command('yum install -y	xdg-user-dirs-gtk	')
    run_command('yum install -y	NetworkManager	')
    run_command('yum install -y	NetworkManager-ppp	')
    run_command('yum install -y	python-gobject-base	')
    run_command('yum install -y	rdma-core	')
    run_command('yum install -y	selinux-policy-targeted	')
    run_command('yum install -y	GConf2	')
    run_command('yum install -y	ModemManager-glib	')
    run_command('yum install -y	NetworkManager-glib	')
    run_command('yum install -y	NetworkManager-libreswan	')
    run_command('yum install -y	NetworkManager-wifi	')
    run_command('yum install -y	PackageKit	')
    run_command('yum install -y	PackageKit-glib	')
    run_command('yum install -y	PackageKit-yum	')
    run_command('yum install -y	abattis-cantarell-fonts	')
    run_command('yum install -y	abrt	')
    run_command('yum install -y	abrt-addon-ccpp	')
    run_command('yum install -y	abrt-addon-kerneloops	')
    run_command('yum install -y	abrt-addon-pstoreoops	')
    run_command('yum install -y	abrt-addon-python	')
    run_command('yum install -y	abrt-addon-vmcore	')
    run_command('yum install -y	abrt-addon-xorg	')
    run_command('yum install -y	abrt-dbus	')
    run_command('yum install -y	abrt-gui	')
    run_command('yum install -y	abrt-gui-libs	')
    run_command('yum install -y	abrt-libs	')
    run_command('yum install -y	abrt-python	')
    run_command('yum install -y	abrt-retrace-client	')
    run_command('yum install -y	accountsservice	')
    run_command('yum install -y	accountsservice-libs	')
    run_command('yum install -y	adwaita-cursor-theme	')
    run_command('yum install -y	adwaita-gtk2-theme	')
    run_command('yum install -y	adwaita-icon-theme	')
    run_command('yum install -y	adwaita-qt5	')
    run_command('yum install -y	appstream-data	')
    run_command('yum install -y	atk	')
    run_command('yum install -y	atkmm	')
    run_command('yum install -y	audit-libs-python	')
    run_command('yum install -y	augeas-libs	')
    run_command('yum install -y	avahi-glib	')
    run_command('yum install -y	avahi-gobject	')
    run_command('yum install -y	avahi-ui-gtk3	')
    run_command('yum install -y	bluez	')
    run_command('yum install -y	bolt	')
    run_command('yum install -y	boost-iostreams	')
    run_command('yum install -y	boost-random	')
    run_command('yum install -y	boost-system	')
    run_command('yum install -y	boost-thread	')
    run_command('yum install -y	bridge-utils	')
    run_command('yum install -y	brlapi	')
    run_command('yum install -y	brltty	')
    run_command('yum install -y	bzip2	')
    run_command('yum install -y	cairo	')
    run_command('yum install -y	cairo-gobject	')
    run_command('yum install -y	cairomm	')
    run_command('yum install -y	cdparanoia-libs	')
    run_command('yum install -y	celt051	')
    run_command('yum install -y	checkpolicy	')
    run_command('yum install -y	cheese-libs	')
    run_command('yum install -y	clutter	')
    run_command('yum install -y	clutter-gst2	')
    run_command('yum install -y	clutter-gst3	')
    run_command('yum install -y	clutter-gtk	')
    run_command('yum install -y	cogl	')
    run_command('yum install -y	color-filesystem	')
    run_command('yum install -y	colord	')
    run_command('yum install -y	colord-gtk	')
    run_command('yum install -y	colord-libs	')
    run_command('yum install -y	control-center-filesystem	')
    run_command('yum install -y	cups-libs	')
    run_command('yum install -y	cups-pk-helper	')
    run_command('yum install -y	cyrus-sasl	')
    run_command('yum install -y	cyrus-sasl-gssapi	')
    run_command('yum install -y	cyrus-sasl-md5	')
    run_command('yum install -y	cyrus-sasl-plain	')
    run_command('yum install -y	cyrus-sasl-scram	')
    run_command('yum install -y	dbus-x11	')
    run_command('yum install -y	dejavu-fonts-common	')
    run_command('yum install -y	dejavu-sans-fonts	')
    run_command('yum install -y	desktop-file-utils	')
    run_command('yum install -y	device-mapper-multipath	')
    run_command('yum install -y	device-mapper-multipath-libs	')
    run_command('yum install -y	dleyna-connector-dbus	')
    run_command('yum install -y	dleyna-core	')
    run_command('yum install -y	dleyna-server	')
    run_command('yum install -y	dosfstools	')
    run_command('yum install -y	dotconf	')
    run_command('yum install -y	efivar-libs	')
    run_command('yum install -y	elfutils	')
    run_command('yum install -y	elfutils-default-yama-scope	')
    run_command('yum install -y	emacs-filesystem	')
    run_command('yum install -y	enchant	')
    run_command('yum install -y	espeak	')
    run_command('yum install -y	evince-libs	')
    run_command('yum install -y	evolution-data-server	')
    run_command('yum install -y	evolution-data-server-langpacks	')
    run_command('yum install -y	exempi	')
    run_command('yum install -y	exiv2-libs	')
    run_command('yum install -y	farstream	')
    run_command('yum install -y	farstream02	')
    run_command('yum install -y	festival	')
    run_command('yum install -y	festival-freebsoft-utils	')
    run_command('yum install -y	festival-lib	')
    run_command('yum install -y	festival-speechtools-libs	')
    run_command('yum install -y	festvox-slt-arctic-hts	')
    run_command('yum install -y	fftw-libs-double	')
    run_command('yum install -y	firewalld-filesystem	')
    run_command('yum install -y	flac-libs	')
    run_command('yum install -y	flatpak	')
    run_command('yum install -y	flatpak-libs	')
    run_command('yum install -y	flite	')
    run_command('yum install -y	folks	')
    run_command('yum install -y	fontconfig	')
    run_command('yum install -y	fontpackages-filesystem	')
    run_command('yum install -y	fprintd	')
    run_command('yum install -y	freerdp-libs	')
    run_command('yum install -y	frei0r-plugins	')
    run_command('yum install -y	fribidi	')
    run_command('yum install -y	fros	')
    run_command('yum install -y	fuse	')
    run_command('yum install -y	fuse-libs	')
    run_command('yum install -y	fwupd	')
    run_command('yum install -y	fwupdate-efi	')
    run_command('yum install -y	fwupdate-libs	')
    run_command('yum install -y	gavl	')
    run_command('yum install -y	gcr	')
    run_command('yum install -y	gd	')
    run_command('yum install -y	gdb	')
    run_command('yum install -y	gdisk	')
    run_command('yum install -y	gdk-pixbuf2	')
    run_command('yum install -y	genisoimage	')
    run_command('yum install -y	geoclue2	')
    run_command('yum install -y	geoclue2-libs	')
    run_command('yum install -y	geocode-glib	')
    run_command('yum install -y	ghostscript	')
    run_command('yum install -y	ghostscript-fonts	')
    run_command('yum install -y	giflib	')
    run_command('yum install -y	gjs	')
    run_command('yum install -y	glibmm24	')
    run_command('yum install -y	glusterfs	')
    run_command('yum install -y	glusterfs-api	')
    run_command('yum install -y	glusterfs-cli	')
    run_command('yum install -y	glusterfs-client-xlators	')
    run_command('yum install -y	glusterfs-libs	')
    run_command('yum install -y	glx-utils	')
    run_command('yum install -y	gnome-abrt	')
    run_command('yum install -y	gnome-bluetooth-libs	')
    run_command('yum install -y	gnome-desktop3	')
    run_command('yum install -y	gnome-keyring	')
    run_command('yum install -y	gnome-keyring-pam	')
    run_command('yum install -y	gnome-menus	')
    run_command('yum install -y	gnome-online-accounts	')
    run_command('yum install -y	gnome-packagekit-common	')
    run_command('yum install -y	gnome-packagekit-installer	')
    run_command('yum install -y	gnome-shell-extension-user-theme	')
    run_command('yum install -y	gnome-video-effects	')
    run_command('yum install -y	gom	')
    run_command('yum install -y	google-noto-emoji-color-fonts	')
    run_command('yum install -y	gperftools-libs	')
    run_command('yum install -y	graphite2	')
    run_command('yum install -y	grilo	')
    run_command('yum install -y	grilo-plugins	')
    run_command('yum install -y	gsm	')
    run_command('yum install -y	gsound	')
    run_command('yum install -y	gspell	')
    run_command('yum install -y	gssdp	')
    run_command('yum install -y	gssproxy	')
    run_command('yum install -y	gstreamer	')
    run_command('yum install -y	gstreamer-plugins-bad-free	')
    run_command('yum install -y	gstreamer-plugins-base	')
    run_command('yum install -y	gstreamer-plugins-good	')
    run_command('yum install -y	gstreamer-tools	')
    run_command('yum install -y	gstreamer1	')
    run_command('yum install -y	gstreamer1-plugins-bad-free	')
    run_command('yum install -y	gstreamer1-plugins-base	')
    run_command('yum install -y	gstreamer1-plugins-good	')
    run_command('yum install -y	gstreamer1-plugins-ugly-free	')
    run_command('yum install -y	gtk-update-icon-cache	')
    run_command('yum install -y	gtk-vnc2	')
    run_command('yum install -y	gtk2	')
    run_command('yum install -y	gtk3	')
    run_command('yum install -y	gtkmm30	')
    run_command('yum install -y	gtksourceview3	')
    run_command('yum install -y	gucharmap-libs	')
    run_command('yum install -y	gupnp	')
    run_command('yum install -y	gupnp-av	')
    run_command('yum install -y	gupnp-dlna	')
    run_command('yum install -y	gupnp-igd	')
    run_command('yum install -y	gvfs	')
    run_command('yum install -y	gvfs-client	')
    run_command('yum install -y	gvnc	')
    run_command('yum install -y	harfbuzz	')
    run_command('yum install -y	harfbuzz-icu	')
    run_command('yum install -y	hicolor-icon-theme	')
    run_command('yum install -y	highcontrast-qt5	')
    run_command('yum install -y	hplip-common	')
    run_command('yum install -y	hplip-libs	')
    run_command('yum install -y	hunspell	')
    run_command('yum install -y	hunspell-en-US	')
    run_command('yum install -y	hyphen	')
    run_command('yum install -y	ibus	')
    run_command('yum install -y	ibus-gtk2	')
    run_command('yum install -y	ibus-gtk3	')
    run_command('yum install -y	ibus-libs	')
    run_command('yum install -y	ibus-setup	')
    run_command('yum install -y	ipset	')
    run_command('yum install -y	ipset-libs	')
    run_command('yum install -y	ipxe-roms-qemu	')
    run_command('yum install -y	iscsi-initiator-utils	')
    run_command('yum install -y	iscsi-initiator-utils-iscsiuio	')
    run_command('yum install -y	iso-codes	')
    run_command('yum install -y	jasper-libs	')
    run_command('yum install -y	jbigkit-libs	')
    run_command('yum install -y	json-glib	')
    run_command('yum install -y	keyutils	')
    run_command('yum install -y	lcms2	')
    run_command('yum install -y	ldns	')
    run_command('yum install -y	libICE	')
    run_command('yum install -y	libSM	')
    run_command('yum install -y	libX11	')
    run_command('yum install -y	libX11-common	')
    run_command('yum install -y	libXau	')
    run_command('yum install -y	libXcomposite	')
    run_command('yum install -y	libXcursor	')
    run_command('yum install -y	libXdamage	')
    run_command('yum install -y	libXdmcp	')
    run_command('yum install -y	libXext	')
    run_command('yum install -y	libXfixes	')
    run_command('yum install -y	libXft	')
    run_command('yum install -y	libXi	')
    run_command('yum install -y	libXinerama	')
    run_command('yum install -y	libXmu	')
    run_command('yum install -y	libXpm	')
    run_command('yum install -y	libXrandr	')
    run_command('yum install -y	libXrender	')
    run_command('yum install -y	libXres	')
    run_command('yum install -y	libXt	')
    run_command('yum install -y	libXtst	')
    run_command('yum install -y	libXv	')
    run_command('yum install -y	libXxf86misc	')
    run_command('yum install -y	libXxf86vm	')
    run_command('yum install -y	libao	')
    run_command('yum install -y	libappstream-glib	')
    run_command('yum install -y	libarchive	')
    run_command('yum install -y	libasyncns	')
    run_command('yum install -y	libatasmart	')
    run_command('yum install -y	libavc1394	')
    run_command('yum install -y	libbasicobjects	')
    run_command('yum install -y	libblockdev	')
    run_command('yum install -y	libblockdev-crypto	')
    run_command('yum install -y	libblockdev-fs	')
    run_command('yum install -y	libblockdev-loop	')
    run_command('yum install -y	libblockdev-mdraid	')
    run_command('yum install -y	libblockdev-part	')
    run_command('yum install -y	libblockdev-swap	')
    run_command('yum install -y	libblockdev-utils	')
    run_command('yum install -y	libbluray	')
    run_command('yum install -y	libbytesize	')
    run_command('yum install -y	libcacard	')
    run_command('yum install -y	libcanberra	')
    run_command('yum install -y	libcdio	')
    run_command('yum install -y	libcdio-paranoia	')
    run_command('yum install -y	libcgroup	')
    run_command('yum install -y	libchamplain	')
    run_command('yum install -y	libchamplain-gtk	')
    run_command('yum install -y	libcollection	')
    run_command('yum install -y	libdmapsharing	')
    run_command('yum install -y	libdv	')
    run_command('yum install -y	libdvdnav	')
    run_command('yum install -y	libdvdread	')
    run_command('yum install -y	libepoxy	')
    run_command('yum install -y	libevdev	')
    run_command('yum install -y	libevent	')
    run_command('yum install -y	libexif	')
    run_command('yum install -y	libfontenc	')
    run_command('yum install -y	libfprint	')
    run_command('yum install -y	libgcab1	')
    run_command('yum install -y	libgdata	')
    run_command('yum install -y	libgdither	')
    run_command('yum install -y	libgee	')
    run_command('yum install -y	libglade2	')
    run_command('yum install -y	libglvnd	')
    run_command('yum install -y	libglvnd-egl	')
    run_command('yum install -y	libglvnd-gles	')
    run_command('yum install -y	libglvnd-glx	')
    run_command('yum install -y	libgnomekbd	')
    run_command('yum install -y	libgovirt	')
    run_command('yum install -y	libgphoto2	')
    run_command('yum install -y	libgsf	')
    run_command('yum install -y	libgtop2	')
    run_command('yum install -y	libgusb	')
    run_command('yum install -y	libgweather	')
    run_command('yum install -y	libgxps	')
    run_command('yum install -y	libibverbs	')
    run_command('yum install -y	libical	')
    run_command('yum install -y	libicu	')
    run_command('yum install -y	libiec61883	')
    run_command('yum install -y	libieee1284	')
    run_command('yum install -y	libimobiledevice	')
    run_command('yum install -y	libini_config	')
    run_command('yum install -y	libinput	')
    run_command('yum install -y	libiptcdata	')
    run_command('yum install -y	libiscsi	')
    run_command('yum install -y	libjpeg-turbo	')
    run_command('yum install -y	libldb	')
    run_command('yum install -y	liblouis	')
    run_command('yum install -y	liblouis-python	')
    run_command('yum install -y	libmediaart	')
    run_command('yum install -y	libmpc	')
    run_command('yum install -y	libmpcdec	')
    run_command('yum install -y	libmtp	')
    run_command('yum install -y	libmusicbrainz5	')
    run_command('yum install -y	libnfsidmap	')
    run_command('yum install -y	libnice	')
    run_command('yum install -y	libnl	')
    run_command('yum install -y	libnm-gtk	')
    run_command('yum install -y	libnma	')
    run_command('yum install -y	libnotify	')
    run_command('yum install -y	liboauth	')
    run_command('yum install -y	libofa	')
    run_command('yum install -y	libogg	')
    run_command('yum install -y	libosinfo	')
    run_command('yum install -y	libpath_utils	')
    run_command('yum install -y	libpeas	')
    run_command('yum install -y	libpeas-gtk	')
    run_command('yum install -y	libpeas-loader-python	')
    run_command('yum install -y	libplist	')
    run_command('yum install -y	libpng	')
    run_command('yum install -y	libpurple	')
    run_command('yum install -y	librados2	')
    run_command('yum install -y	libraw1394	')
    run_command('yum install -y	librbd1	')
    run_command('yum install -y	librdmacm	')
    run_command('yum install -y	libref_array	')
    run_command('yum install -y	libreport	')
    run_command('yum install -y	libreport-centos	')
    run_command('yum install -y	libreport-cli	')
    run_command('yum install -y	libreport-filesystem	')
    run_command('yum install -y	libreport-gtk	')
    run_command('yum install -y	libreport-plugin-mantisbt	')
    run_command('yum install -y	libreport-plugin-reportuploader	')
    run_command('yum install -y	libreport-plugin-rhtsupport	')
    run_command('yum install -y	libreport-plugin-ureport	')
    run_command('yum install -y	libreport-python	')
    run_command('yum install -y	libreport-web	')
    run_command('yum install -y	libreswan	')
    run_command('yum install -y	libseccomp	')
    run_command('yum install -y	libsecret	')
    run_command('yum install -y	libsemanage-python	')
    run_command('yum install -y	libshout	')
    run_command('yum install -y	libsigc++20	')
    run_command('yum install -y	libsmbclient	')
    run_command('yum install -y	libsmbios	')
    run_command('yum install -y	libsndfile	')
    run_command('yum install -y	libspectre	')
    run_command('yum install -y	libsrtp	')
    run_command('yum install -y	libtalloc	')
    run_command('yum install -y	libtar	')
    run_command('yum install -y	libtdb	')
    run_command('yum install -y	libtevent	')
    run_command('yum install -y	libthai	')
    run_command('yum install -y	libtheora	')
    run_command('yum install -y	libtiff	')
    run_command('yum install -y	libtirpc	')
    run_command('yum install -y	libtool-ltdl	')
    run_command('yum install -y	libudisks2	')
    run_command('yum install -y	libusal	')
    run_command('yum install -y	libusbmuxd	')
    run_command('yum install -y	libusbx	')
    run_command('yum install -y	libv4l	')
    run_command('yum install -y	libverto-tevent	')
    run_command('yum install -y	libvirt-daemon	')
    run_command('yum install -y	libvirt-gconfig	')
    run_command('yum install -y	libvirt-glib	')
    run_command('yum install -y	libvirt-gobject	')
    run_command('yum install -y	libvirt-libs	')
    run_command('yum install -y	libvisual	')
    run_command('yum install -y	libvorbis	')
    run_command('yum install -y	libvpx	')
    run_command('yum install -y	libwacom	')
    run_command('yum install -y	libwacom-data	')
    run_command('yum install -y	libwayland-client	')
    run_command('yum install -y	libwayland-cursor	')
    run_command('yum install -y	libwayland-egl	')
    run_command('yum install -y	libwayland-server	')
    run_command('yum install -y	libwbclient	')
    run_command('yum install -y	libwebp	')
    run_command('yum install -y	libwnck3	')
    run_command('yum install -y	libxcb	')
    run_command('yum install -y	libxkbcommon	')
    run_command('yum install -y	libxkbcommon-x11	')
    run_command('yum install -y	libxkbfile	')
    run_command('yum install -y	libxklavier	')
    run_command('yum install -y	libxml2-python	')
    run_command('yum install -y	libxshmfence	')
    run_command('yum install -y	libxslt	')
    run_command('yum install -y	llvm-private	')
    run_command('yum install -y	lockdev	')
    run_command('yum install -y	lz4	')
    run_command('yum install -y	lzop	')
    run_command('yum install -y	mdadm	')
    run_command('yum install -y	meanwhile	')
    run_command('yum install -y	mesa-dri-drivers	')
    run_command('yum install -y	mesa-filesystem	')
    run_command('yum install -y	mesa-libEGL	')
    run_command('yum install -y	mesa-libGL	')
    run_command('yum install -y	mesa-libgbm	')
    run_command('yum install -y	mesa-libglapi	')
    run_command('yum install -y	mobile-broadband-provider-info	')
    run_command('yum install -y	mokutil	')
    run_command('yum install -y	mozjs52	')
    run_command('yum install -y	mpfr	')
    run_command('yum install -y	mpg123-libs	')
    run_command('yum install -y	mtdev	')
    run_command('yum install -y	mtools	')
    run_command('yum install -y	mutter	')
    run_command('yum install -y	nautilus-extensions	')
    run_command('yum install -y	ncompress	')
    run_command('yum install -y	neon	')
    run_command('yum install -y	net-snmp-libs	')
    run_command('yum install -y	netcf-libs	')
    run_command('yum install -y	nfs-utils	')
    run_command('yum install -y	nmap-ncat	')
    run_command('yum install -y	numad	')
    run_command('yum install -y	openjpeg-libs	')
    run_command('yum install -y	opus	')
    run_command('yum install -y	orc	')
    run_command('yum install -y	osinfo-db	')
    run_command('yum install -y	osinfo-db-tools	')
    run_command('yum install -y	pakchois	')
    run_command('yum install -y	pango	')
    run_command('yum install -y	pangomm	')
    run_command('yum install -y	pciutils	')
    run_command('yum install -y	pcre2	')
    run_command('yum install -y	pcre2-utf16	')
    run_command('yum install -y	perl	')
    run_command('yum install -y	perl-Carp	')
    run_command('yum install -y	perl-Encode	')
    run_command('yum install -y	perl-Exporter	')
    run_command('yum install -y	perl-File-Path	')
    run_command('yum install -y	perl-File-Temp	')
    run_command('yum install -y	perl-Filter	')
    run_command('yum install -y	perl-Getopt-Long	')
    run_command('yum install -y	perl-HTTP-Tiny	')
    run_command('yum install -y	perl-PathTools	')
    run_command('yum install -y	perl-Pod-Escapes	')
    run_command('yum install -y	perl-Pod-Perldoc	')
    run_command('yum install -y	perl-Pod-Simple	')
    run_command('yum install -y	perl-Pod-Usage	')
    run_command('yum install -y	perl-Scalar-List-Utils	')
    run_command('yum install -y	perl-Socket	')
    run_command('yum install -y	perl-Storable	')
    run_command('yum install -y	perl-Text-ParseWords	')
    run_command('yum install -y	perl-Time-HiRes	')
    run_command('yum install -y	perl-Time-Local	')
    run_command('yum install -y	perl-constant	')
    run_command('yum install -y	perl-libs	')
    run_command('yum install -y	perl-macros	')
    run_command('yum install -y	perl-parent	')
    run_command('yum install -y	perl-podlators	')
    run_command('yum install -y	perl-threads	')
    run_command('yum install -y	perl-threads-shared	')
    run_command('yum install -y	pinentry-gtk	')
    run_command('yum install -y	pixman	')
    run_command('yum install -y	policycoreutils-python	')
    run_command('yum install -y	poppler	')
    run_command('yum install -y	poppler-data	')
    run_command('yum install -y	poppler-glib	')
    run_command('yum install -y	psmisc	')
    run_command('yum install -y	pulseaudio	')
    run_command('yum install -y	pulseaudio-gdm-hooks	')
    run_command('yum install -y	pulseaudio-libs	')
    run_command('yum install -y	pulseaudio-libs-glib2	')
    run_command('yum install -y	pulseaudio-module-bluetooth	')
    run_command('yum install -y	pycairo	')
    run_command('yum install -y	pygobject2	')
    run_command('yum install -y	pygtk2	')
    run_command('yum install -y	pygtk2-libglade	')
    run_command('yum install -y	python-IPy	')
    run_command('yum install -y	python-augeas	')
    run_command('yum install -y	python-brlapi	')
    run_command('yum install -y	python-ethtool	')
    run_command('yum install -y	python-firewall	')
    run_command('yum install -y	python-gobject	')
    run_command('yum install -y	python-inotify	')
    run_command('yum install -y	python-meh	')
    run_command('yum install -y	python-six	')
    run_command('yum install -y	python2-futures	')
    run_command('yum install -y	python2-pyatspi	')
    run_command('yum install -y	qemu-img	')
    run_command('yum install -y	qemu-kvm	')
    run_command('yum install -y	qemu-kvm-common	')
    run_command('yum install -y	qt5-qtbase	')
    run_command('yum install -y	qt5-qtbase-common	')
    run_command('yum install -y	qt5-qtbase-gui	')
    run_command('yum install -y	quota	')
    run_command('yum install -y	quota-nls	')
    run_command('yum install -y	radvd	')
    run_command('yum install -y	redhat-menus	')
    run_command('yum install -y	rest	')
    run_command('yum install -y	rpcbind	')
    run_command('yum install -y	rtkit	')
    run_command('yum install -y	samba-client-libs	')
    run_command('yum install -y	samba-common	')
    run_command('yum install -y	samba-common-libs	')
    run_command('yum install -y	sane-backends	')
    run_command('yum install -y	sane-backends-libs	')
    run_command('yum install -y	satyr	')
    run_command('yum install -y	sbc	')
    run_command('yum install -y	seabios-bin	')
    run_command('yum install -y	seavgabios-bin	')
    run_command('yum install -y	setools-libs	')
    run_command('yum install -y	setroubleshoot-plugins	')
    run_command('yum install -y	setroubleshoot-server	')
    run_command('yum install -y	sgabios-bin	')
    run_command('yum install -y	shim-x64	')
    run_command('yum install -y	sos	')
    run_command('yum install -y	sound-theme-freedesktop	')
    run_command('yum install -y	soundtouch	')
    run_command('yum install -y	sox	')
    run_command('yum install -y	speech-dispatcher	')
    run_command('yum install -y	speech-dispatcher-python	')
    run_command('yum install -y	speex	')
    run_command('yum install -y	spice-glib	')
    run_command('yum install -y	spice-gtk3	')
    run_command('yum install -y	spice-server	')
    run_command('yum install -y	startup-notification	')
    run_command('yum install -y	systemd-python	')
    run_command('yum install -y	taglib	')
    run_command('yum install -y	tcp_wrappers	')
    run_command('yum install -y	telepathy-farstream	')
    run_command('yum install -y	telepathy-filesystem	')
    run_command('yum install -y	telepathy-gabble	')
    run_command('yum install -y	telepathy-glib	')
    run_command('yum install -y	telepathy-haze	')
    run_command('yum install -y	telepathy-logger	')
    run_command('yum install -y	telepathy-mission-control	')
    run_command('yum install -y	telepathy-salut	')
    run_command('yum install -y	totem-pl-parser	')
    run_command('yum install -y	tracker	')
    run_command('yum install -y	udisks2	')
    run_command('yum install -y	unbound-libs	')
    run_command('yum install -y	unzip	')
    run_command('yum install -y	upower	')
    run_command('yum install -y	urw-fonts	')
    run_command('yum install -y	usbmuxd	')
    run_command('yum install -y	usbredir	')
    run_command('yum install -y	userspace-rcu	')
    run_command('yum install -y	volume_key-libs	')
    run_command('yum install -y	vte-profile	')
    run_command('yum install -y	vte291	')
    run_command('yum install -y	wavpack	')
    run_command('yum install -y	webkitgtk3	')
    run_command('yum install -y	webkitgtk4	')
    run_command('yum install -y	webkitgtk4-jsc	')
    run_command('yum install -y	webkitgtk4-plugin-process-gtk2	')
    run_command('yum install -y	webrtc-audio-processing	')
    run_command('yum install -y	xcb-util	')
    run_command('yum install -y	xcb-util-image	')
    run_command('yum install -y	xcb-util-keysyms	')
    run_command('yum install -y	xcb-util-renderutil	')
    run_command('yum install -y	xcb-util-wm	')
    run_command('yum install -y	xdg-desktop-portal	')
    run_command('yum install -y	xdg-user-dirs	')
    run_command('yum install -y	xdg-utils	')
    run_command('yum install -y	xkeyboard-config	')
    run_command('yum install -y	xml-common	')
    run_command('yum install -y	xmlrpc-c	')
    run_command('yum install -y	xmlrpc-c-client	')
    run_command('yum install -y	xorg-x11-font-utils	')
    run_command('yum install -y	xorg-x11-server-utils	')
    run_command('yum install -y	xorg-x11-xauth	')
    run_command('yum install -y	xorg-x11-xinit	')
    run_command('yum install -y	xorg-x11-xkb-utils	')
    run_command('yum install -y	yajl	')
    run_command('yum install -y	zenity	')
    run_command('yum install -y	zip	')
    run_command('yum install -y	NetworkManager-libnm	')
    run_command('yum install -y	NetworkManager-team	')
    run_command('yum install -y	NetworkManager-tui	')
    run_command('yum install -y	audit	')
    run_command('yum install -y	audit-libs	')
    run_command('yum install -y	avahi-autoipd	')
    run_command('yum install -y	avahi-libs	')
    run_command('yum install -y	bzip2-libs	')
    run_command('yum install -y	cryptsetup-libs	')
    run_command('yum install -y	cyrus-sasl-lib	')
    run_command('yum install -y	dbus	')
    run_command('yum install -y	dbus-libs	')
    run_command('yum install -y	device-mapper	')
    run_command('yum install -y	device-mapper-event	')
    run_command('yum install -y	device-mapper-event-libs	')
    run_command('yum install -y	device-mapper-libs	')
    run_command('yum install -y	device-mapper-persistent-data	')
    run_command('yum install -y	elfutils-libelf	')
    run_command('yum install -y	elfutils-libs	')
    run_command('yum install -y	firewalld	')
    run_command('yum install -y	freetype	')
    run_command('yum install -y	gettext	')
    run_command('yum install -y	gettext-libs	')
    run_command('yum install -y	glib2	')
    run_command('yum install -y	gobject-introspection	')
    run_command('yum install -y	gsettings-desktop-schemas	')
    run_command('yum install -y	keyutils-libs	')
    run_command('yum install -y	kpartx	')
    run_command('yum install -y	krb5-libs	')
    run_command('yum install -y	libdrm	')
    run_command('yum install -y	libgudev1	')
    run_command('yum install -y	libnl3	')
    run_command('yum install -y	libnl3-cli	')
    run_command('yum install -y	libproxy	')
    run_command('yum install -y	libselinux	')
    run_command('yum install -y	libselinux-python	')
    run_command('yum install -y	libselinux-utils	')
    run_command('yum install -y	libsemanage	')
    run_command('yum install -y	libsepol	')
    run_command('yum install -y	libsoup	')
    run_command('yum install -y	libverto	')
    run_command('yum install -y	libxml2	')
    run_command('yum install -y	lvm2	')
    run_command('yum install -y	lvm2-libs	')
    run_command('yum install -y	openssl	')
    run_command('yum install -y	openssl-libs	')
    run_command('yum install -y	pciutils-libs	')
    run_command('yum install -y	pinentry	')
    run_command('yum install -y	policycoreutils	')
    run_command('yum install -y	selinux-policy	')
    run_command('yum install -y	systemd	')
    run_command('yum install -y	systemd-libs	')
    run_command('yum install -y	systemd-sysv	')
    run_command('yum install -y	tcp_wrappers-libs	')
    run_command('yum install -y	gnome-boxes	')


def groupinstall_font():
    # 安装groupinstall font
    run_command('yum install -y	cjkuni-uming-fonts	')
    run_command('yum install -y	dejavu-sans-fonts	')
    run_command('yum install -y	dejavu-sans-mono-fonts	')
    run_command('yum install -y	dejavu-serif-fonts   	')
    run_command('yum install -y	gnu-free-mono-fonts	')
    run_command('yum install -y	gnu-free-sans-fonts	')
    run_command('yum install -y	gnu-free-serif-fonts	')
    run_command('yum install -y	google-crosextra-caladea-fonts	')
    run_command('yum install -y	google-crosextra-carlito-fonts	')
    run_command('yum install -y	google-noto-emoji-fonts	')
    run_command('yum install -y	jomolhari-fonts	')
    run_command('yum install -y	khmeros-base-fonts	')
    run_command('yum install -y	liberation-mono-fonts	')
    run_command('yum install -y	liberation-sans-fonts	')
    run_command('yum install -y	liberation-serif-fonts	')
    run_command('yum install -y	lklug-fonts	')
    run_command('yum install -y	lohit-assamese-fonts	')
    run_command('yum install -y	lohit-bengali-fonts	')
    run_command('yum install -y	lohit-devanagari-fonts	')
    run_command('yum install -y	lohit-gujarati-fonts	')
    run_command('yum install -y	lohit-kannada-fonts	')
    run_command('yum install -y	lohit-malayalam-fonts	')
    run_command('yum install -y	lohit-marathi-fonts	')
    run_command('yum install -y	lohit-nepali-fonts	')
    run_command('yum install -y	lohit-oriya-fonts	')
    run_command('yum install -y	lohit-punjabi-fonts	')
    run_command('yum install -y	lohit-tamil-fonts	')
    run_command('yum install -y	lohit-telugu-fonts	')
    run_command('yum install -y	madan-fonts	')
    run_command('yum install -y	nhn-nanum-gothic-fonts	')
    run_command('yum install -y	open-sans-fonts	')
    run_command('yum install -y	overpass-fonts	')
    run_command('yum install -y	paktype-naskh-basic-fonts	')
    run_command('yum install -y	paratype-pt-sans-fonts	')
    run_command('yum install -y	sil-abyssinica-fonts	')
    run_command('yum install -y	sil-nuosu-fonts	')
    run_command('yum install -y	sil-padauk-fonts	')
    run_command('yum install -y	smc-meera-fonts	')
    run_command('yum install -y	stix-fonts	')
    run_command('yum install -y	thai-scalable-waree-fonts	')
    run_command('yum install -y	ucs-miscfixed-fonts	')
    run_command('yum install -y	vlgothic-fonts	')
    run_command('yum install -y	wqy-microhei-fonts	')
    run_command('yum install -y	wqy-zenhei-fonts	')
    run_command('yum install -y	dejavu-fonts-common	')
    run_command('yum install -y	fontpackages-filesystem	')
    run_command('yum install -y	gnu-free-fonts-common	')
    run_command('yum install -y	khmeros-fonts-common	')
    run_command('yum install -y	liberation-fonts-common	')
    run_command('yum install -y	nhn-nanum-fonts-common	')
    run_command('yum install -y	smc-fonts-common	')
    run_command('yum install -y	thai-scalable-fonts-common	')


def main70(repo_content):
    repo_content = repo_content.replace('_', '=')
    repo_content = base64.b64decode(repo_content).decode('utf-8')
    uuidfilename = uuid.uuid4().hex
    local_repo_file_path = '/root/' + uuidfilename + '.repo'
    with open(local_repo_file_path, 'w') as file:
        file.write(repo_content)
    if not os.path.exists(realtek_driver_file_path):
        with open(realtek_driver_file_path, 'w') as file:
            file.write(config_realtek_driver)
    with settings(hide('warnings', 'output')):
        run_command('mv /etc/yum.repos.d/* /root/')
        upload_file(f"{local_repo_file_path}", f"{ssh_repo_file_path}")

        # 获取当前内核版本 方便后续卸载
        result = run('uname -r')
        kernel_version = result.stdout

        run_command('yum makecache')
        run_command('setenforce 0')
        run_command('yum install yum-utils -y')
        run_command('yumdownloader filesystem  --destdir=/root/')
        run_command('rpm -Uvh /root/filesystem*')
        run_command('rpm -e centos-release --nodeps')
        run_command('rpm -e gnome-classic-session --nodeps')
        run_command('rpm -e gnome-initial-setup --nodeps')
        run_command('rpm -e gnome-shell-extension-alternate-tab --nodeps')
        run_command('rpm -e gnome-shell-extension-places-menu --nodeps ')
        run_command('rpm -e gnome-shell-extension-launch-new-instance --nodeps ')
        run_command('rpm -e gnome-shell-extension-window-list --nodeps')

        run_command('mv /etc/yum.repos.d/NFS-4.0-Base.repo /root/')
        run_command('yum update -y')
        run_command('mv /etc/yum.repos.d/NFS-4.0-Base.repo /root/')
        run_command(f'rpm -e kernel-{kernel_version} --nodeps')
        run_command(f'rpm -e kernel-devel-{kernel_version} --nodeps')
        run_command(f'rpm -e kernel-core-{kernel_version} --nodeps')
        run_command('grub2-mkconfig -o /boot/grub2/grub.cfg')
        run_command('grub2-mkconfig -o /boot/efi/EFI/NFS/grub.cfg')
        run_command('rpm -e centos-logos  --nodeps')
        run_command('yum install nfs-logos -y')
        run_command('yum install nfs-indexhtml -y')
        #run_command('yum groupinstall gnome -y')
        groupinstall_gnome()
        run_command('yum install gnome-shell-extension-dash-to-panel -y')
        run_command('yum install xorg-x11-server-common -y')
        run_command('yum install xorg-x11-server-Xorg -y')
        run_command('yum install xorg-x11-drv-* -y')
        #run_command('yum groupinstall font -y')
        groupinstall_font()
        run_command('yum install kernel-headers -y')
        run_command('yum install kernel-devel -y')
        run_command('yum install kmod* -y')
        upload_file(f"{realtek_driver_file_path}",
                    "/etc/systemd/system/")
        run_command('systemctl enable load-realtek-driver.service')
        run_command('systemctl set-default graphical.target')
        run_command('systemctl enable gdm')
        run_command('mv /root/NFS-4.0-Base.repo /etc/yum.repos.d/')
        local(f'rm -rf {local_repo_file_path}')
        run_command(f'rm -rf {ssh_repo_file_path}/{uuidfilename}.repo')
        run_command('echo 迁移完成！')


def main71_75(repo_content):
    repo_content = repo_content.replace('_', '=')
    repo_content = base64.b64decode(repo_content).decode('utf-8')
    uuidfilename = uuid.uuid4().hex
    local_repo_file_path = '/root/' + uuidfilename + '.repo'
    with open(local_repo_file_path, 'w') as file:
        file.write(repo_content)
    if not os.path.exists(realtek_driver_file_path):
        with open(realtek_driver_file_path, 'w') as file:
            file.write(config_realtek_driver)
    with settings(hide('warnings', 'output')):
        run_command('mv /etc/yum.repos.d/* /root/')
        upload_file(f"{local_repo_file_path}", f"{ssh_repo_file_path}")

        # 获取当前内核版本 方便后续卸载
        result = run('uname -r')
        kernel_version = result.stdout

        run_command('yum -y install yum-utils')

        run_command('yum clean all')
        run_command('yum makecache')
        run_command('mv /etc/yum.repos.d/NFS-4.0-Base.repo /root/')
        # 卸载剩余centos软件包
        run_command('rpm -e centos-release --nodeps')
        run_command('rpm -e centos-logos --nodeps')
        run_command('yumdownloader filesystem --destdir=/root/')
        run_command('rpm -Uvh /root/filesystem* ')
        run_command('yumdownloader samba-common --destdir=/root/')
        run_command('rpm -Uvh /root/samba-common* --nodeps')
        run_command('rpm -e python-inotify  --nodeps')
        run_command('rpm -e man-pages-zh-CN  --nodeps')
        run_command('rpm -e adwaita-qt5 --nodeps')
        run_command('rpm -e pycairo --nodeps')
        run_command('rpm -e gnome-classic-session --nodeps')
        run_command('rpm -e gnome-initial-setup --nodeps')
        run_command('rpm -e gnome-shell-extension-alternate-tab --nodeps')
        run_command('rpm -e gnome-shell-extension-places-menu --nodeps ')
        run_command('rpm -e gnome-shell-extension-launch-new-instance --nodeps ')
        run_command('rpm -e gnome-shell-extension-window-list --nodeps')
        run_command('rpm -e ipa-python --nodeps')
        # 卸载原有内核
        run_command('setenforce 0')
        run_command('yum update -y')
        run_command(f'rpm -e kernel-{kernel_version} --nodeps')
        run_command(f'rpm -e kernel-devel-{kernel_version} --nodeps')
        run_command(f'rpm -e kernel-core-{kernel_version} --nodeps')
        run_command('mv /etc/yum.repos.d/NFS-4.0-Base.repo /root/')
        run_command('rpm -e centos-indexhtml --nodeps')
        run_command('rpm -e gnome-backgrounds --nodeps')
        run_command('yum install nfs-logos -y')
        run_command('yum install nfs-release -y')
        run_command('grub2-mkconfig -o /boot/grub2/grub.cfg')
        run_command('grub2-mkconfig -o /boot/efi/EFI/NFS/grub.cfg')
        # 安装gnome图形界面
        run_command('mv /etc/yum.repos.d/NFS-4.0-Base.repo /root/')
        #run_command('yum groupinstall gnome -y')
        groupinstall_gnome()
        run_command('yum install xorg-x11-server-common -y')
        run_command('yum install xorg-x11-server-Xorg -y')
        run_command('yum install xorg-x11-drv-* -y')
        #run_command('yum groupinstall font -y')
        groupinstall_font()
        run_command('yum install kernel-headers -y')
        run_command('yum install kernel-devel -y')
        run_command('yum install kmod* -y')
        upload_file(f"{realtek_driver_file_path}",
                    "/etc/systemd/system/")
        run_command('systemctl enable load-realtek-driver.service')
        run_command('systemctl set-default graphical.target')
        run_command('systemctl enable gdm')
        run_command('mv /root/NFS-4.0-Base.repo /etc/yum.repos.d/')
        local(f'rm -rf {local_repo_file_path}')
        run_command(f'rm -rf {ssh_repo_file_path}/{uuidfilename}.repo')
        run_command('echo 迁移完成！')


def main76(repo_content):
    repo_content = repo_content.replace('_', '=')
    repo_content = base64.b64decode(repo_content).decode('utf-8')
    uuidfilename = uuid.uuid4().hex
    local_repo_file_path = '/root/' + uuidfilename + '.repo'
    with open(local_repo_file_path, 'w') as file:
        file.write(repo_content)
    if not os.path.exists(realtek_driver_file_path):
        with open(realtek_driver_file_path, 'w') as file:
            file.write(config_realtek_driver)
    with settings(hide('warnings', 'output')):
        run_command('mv /etc/yum.repos.d/* /root/')
        upload_file(f"{local_repo_file_path}", f"{ssh_repo_file_path}")

        run_command('ps -ef|grep "PackageKit" |grep -v |grep |awk"{print $2}"|xargs kill -9')
        # 获取当前内核版本 方便后续卸载
        result = run('uname -r')
        kernel_version = result.stdout

        run_command('yum -y install yum-utils')

        run_command('yum clean all')
        run_command('yum makecache')
        run_command('mv /etc/yum.repos.d/NFS-4.0-Base.repo /root/')
        # 卸载剩余centos软件包
        run_command('rpm -e centos-release --nodeps')
        run_command('rpm -e centos-logos --nodeps')
        run_command('yumdownloader filesystem --destdir=/root/')
        run_command('rpm -Uvh /root/filesystem* ')
        # 卸载原有内核
        run_command('setenforce 0')
        run_command('yum install nfs-logos -y')
        run_command('yum install nfs-release -y')
        run_command('mv /etc/yum.repos.d/NFS-4.0-Base.repo /root/')
        run_command('yum update -y')
        run_command(f'rpm -e kernel-{kernel_version} --nodeps')
        run_command(f'rpm -e kernel-devel-{kernel_version} --nodeps')
        run_command(f'rpm -e kernel-core-{kernel_version} --nodeps')
        run_command('grub2-mkconfig -o /boot/grub2/grub.cfg')
        run_command('grub2-mkconfig -o /boot/efi/EFI/NFS/grub.cfg')
        # 安装gnome图形界面
        run_command('mv /etc/yum.repos.d/NFS-4.0-Base.repo /root/')
        #run_command('yum groupinstall gnome -y')
        groupinstall_gnome()
        run_command('yum install xorg-x11-server-common -y')
        run_command('yum install xorg-x11-server-Xorg -y')
        run_command('yum install xorg-x11-drv-* -y')
        #run_command('yum groupinstall font -y')
        groupinstall_font()
        run_command('yum install kernel-headers -y')
        run_command('yum install kernel-devel -y')
        run_command('yum install kmod* -y')
        upload_file(f"{realtek_driver_file_path}",
                    "/etc/systemd/system/")
        run_command('systemctl enable load-realtek-driver.service')
        run_command('systemctl set-default graphical.target')
        run_command('systemctl enable gdm')
        run_command('mv /root/NFS-4.0-Base.repo /etc/yum.repos.d/')
        local(f'rm -rf {local_repo_file_path}')
        run_command(f'rm -rf {ssh_repo_file_path}/{uuidfilename}.repo')
        run_command('echo 迁移完成！')


def main77_79(repo_content):
    repo_content = repo_content.replace('_', '=')
    repo_content = base64.b64decode(repo_content).decode('utf-8')
    uuidfilename = uuid.uuid4().hex
    local_repo_file_path = '/root/' + uuidfilename + '.repo'
    with open(local_repo_file_path, 'w') as file:
        file.write(repo_content) 
    if not os.path.exists(local_seconfig_file_path):
        with open(local_seconfig_file_path, 'w') as file:
            file.write(config_content)
    if not os.path.exists(realtek_driver_file_path):
        with open(realtek_driver_file_path, 'w') as file:
            file.write(config_realtek_driver)
    with settings(hide('warnings', 'output')):
        run_command('ps -ef|grep "PackageKit" |grep -v |grep |awk"{print $2}"|xargs kill -9')
        upload_file("/opt/nfs_migration_v2/backend/lixian_char.tar.gz", "/root")
        run_command('tar -xvf /root/lixian_char.tar.gz')
        run_command('rpm -Uvh /root/lixian_char/*.rpm --nodeps --force')
        run_command('mv /etc/yum.repos.d/* /root/')
        upload_file(f"{local_repo_file_path}", f"{ssh_repo_file_path}")

        run_command('yum clean all')
        run_command('yum makecache')
        run_command('rpm -e sysvinit-tools --nodeps')
        run_command('mv /etc/yum /root/')
        run_command('dnf -y --allowerasing --setopt=deltarpm=false distro-sync --nogpgcheck ')
        #添加配置引导菜单安装图形界面
        run_command('grub2-mkconfig -o /boot/grub2/grub.cfg')
        run_command('grub2-mkconfig -o /boot/efi/EFI/NFS/grub.cfg')
        run_command('rpm -e centos-release --nodeps')
        run_command('rpm -e centos-logos --nodeps')
        run_command('yum install nfs-release -y')
        run_command('mv /etc/yum.repos.d/Nfs-Base.repo  /root/ ')
        run_command('mv /etc/yum.repos.d/Nfs-Media.repo /root/')
        run_command('yum install gdm -y')
        run_command('yum install gnome-common -y')
        run_command('yum install gnome-menus -y')
        run_command('yum install gnome-terminal -y')
        run_command('yum install gnome-shell-extension-dash-to-panel.noarch -y')
        run_command('yum install nemo -y')
        run_command('yum install gnome-shell-extension-apps-menu.noarch -y')
        #修复网络和ssh断开连接问题
        run_command('cp /etc/firewalld/firewalld.conf /etc/firewalld/firewalld.conf.backup')
        run_command("sed -i 's/IndividualCalls=no/IndividualCalls=yes/g' /etc/firewalld/firewalld.conf")
        run_command('systemctl restart firewalld')
        run_command('chmod 0600 /etc/ssh/ssh_host_rsa_key ')
        run_command('chmod 0600 /etc/ssh/ssh_host_ecdsa_key ')
        run_command('chmod 0600 /etc/ssh/ssh_host_ed25519_key')
        run_command('systemctl restart sshd')
        groupinstall_font()
        groupinstall_gnome()
        run_command('yum install kernel-headers -y')
        run_command('yum install kernel-devel -y')
        run_command('yum install kmod* -y')
        upload_file(f"{realtek_driver_file_path}",
                    "/etc/systemd/system/")
        run_command('systemctl enable load-realtek-driver.service')
        run_command('systemctl set-default graphical')
        run_command('systemctl enable gdm')
        run_command('rm -rf /boot/loader/entries/*-0-rescue.conf')
        run_command('rm -rf /boot/loader/entries/*.el7.x86_64.conf')
        run_command('mv /root/Nfs-Base.repo /etc/yum.repos.d/')
        run_command('mv /root/Nfs-Media.repo /etc/yum.repos.d/')
        upload_file(f"{local_seconfig_file_path}",
                    "/etc/selinux/")  # 注意需要检测一下执行机器的selinux的配置文件确定disable，或准备一个已经永久关闭selinux的配置文件上传
        local(f'rm -rf {local_repo_file_path}')
        run_command(f'rm -rf {ssh_repo_file_path}/{uuidfilename}.repo')
        run_command('chmod 0600 /etc/ssh/ssh_host_rsa_key ')
        run_command('chmod 0600 /etc/ssh/ssh_host_ecdsa_key ')
        run_command('chmod 0600 /etc/ssh/ssh_host_ed25519_key')
        run_command('systemctl restart sshd')
        run_command('echo 迁移完成！')


def main80_85(repo_content):
    # 更新远程镜像源
    repo_content = repo_content.replace('_', '=')
    repo_content = base64.b64decode(repo_content).decode('utf-8')
    uuidfilename = uuid.uuid4().hex
    local_repo_file_path = '/root/' + uuidfilename + '.repo'
    with open(local_repo_file_path, 'w') as file:
        file.write(repo_content)
    if not os.path.exists(local_seconfig_file_path):
        with open(local_seconfig_file_path, 'w') as file:
            file.write(config_content)
    with settings(hide('warnings', 'output')):
        run_command('mv /etc/yum.repos.d/* /root/')
        upload_file(f"{local_repo_file_path}", f"{ssh_repo_file_path}")
        run_command('yum clean all')
        run_command('yum makecache')
        # 获取当前内核版本 方便后续卸载
        result = run('uname -r')
        kernel_version = result.stdout

        # 关闭一些服务,提前安装一些软件包确保不影响升级
        run_command('setenforce 0')
        run_command('kill -TERM 1')
        run_command('rpm -e centos-indexhtml --nodeps')
        run_command('yum install yum-utils -y')
        run_command('yumdownloader kmod-kvdo  --destdir=/root/')
        run_command('rpm -Uvh /root/kmod-kvdo* --nodeps')
        run_command('yum update dnf -y')
        run_command('yumdownloader filesystem  --destdir=/root/')
        run_command('rpm -Uvh /root/filesystem* ')
        run_command('rpm -e centos-linux-release --nodeps')
        run_command('rpm -e centos-linux-repos --nodeps')
        run_command('rpm -e centos-gpg-keys --nodeps')
        run_command('rpm -e centos-logos --nodeps')
        run_command('rpm -e centos-backgrounds --nodeps')
        run_command('rpm -e centos-logos-httpd --nodeps')
        # 开始升级
        run_command('dnf -y  --allowerasing --setopt=deltarpm=false distro-sync --nogpgcheck')

        # 卸载剩余centos软件包
        run_command('rpm --rebuilddb')
        run_command(f'rpm -e kernel-{kernel_version} --nodeps')
        run_command(f'rpm -e kernel-core-{kernel_version} --nodeps')
        run_command(f'rpm -e kernel-modules-{kernel_version} --nodeps')
        run_command('grub2-mkconfig -o /boot/grub2/grub.cfg')
        run_command('grub2-mkconfig -o /boot/efi/EFI/NFS/grub.cfg')
        #保证源正确性
        run_command('mv /etc/yum.repos.d/Nfs-Base.repo  /root/ ')
        run_command('mv /etc/yum.repos.d/NFS-Base.repo  /root/ ')
        run_command('mv /etc/yum.repos.d/Nfs-Media.repo /root/')
        run_command('yum install nfs-release -y')
        run_command('mv /etc/yum.repos.d/Nfs-Base.repo  /root/ ')
        run_command('mv /etc/yum.repos.d/NFS-Base.repo  /root/ ')
        run_command('mv /etc/yum.repos.d/Nfs-Media.repo /root/')

        # 安装NFS系列图形界面
        run_command('yum install nfs-logos -y')
        run_command('yum install nfs-backgrounds -y')
        run_command('yum groupinstall gnome -y')
        run_command('yum install gnome-* -y')
        run_command('yum install nemo -y')
        run_command('yum install xorg-x11-server-common -y')
        run_command('yum install xorg-x11-server-Xorg -y')
        run_command('yum install xorg-x11-drv-* -y')
        groupinstall_font()
        run_command('yum install kernel-headers -y')
        run_command('yum install kernel-devel -y')
        run_command('yum install kmod* -y')

        # 设置图形界面显示生效
        run_command('kill -TERM 1')
        run_command('systemctl set-default graphical.target')
        run_command('systemctl enable gdm')
        run_command('rm -rf /boot/loader/entries/*-0-rescue.conf')
        run_command('rm -rf /boot/loader/entries/*.el8.x86_64.conf')
        run_command('mv /etc/selinux/config /root/')
        upload_file(f"{local_seconfig_file_path}",
                    "/etc/selinux/")  # 注意需要检测一下执行机器的selinux的配置文件确定disable，或准备一个已经永久关闭selinux的配置文件上传
        local(f'rm -rf {local_repo_file_path}')
        run_command(f'rm -rf {ssh_repo_file_path}/{uuidfilename}.repo')
        run_command('mv /root/Nfs-Base.repo /etc/yum.repos.d/')
        run_command('mv /root/NFS-Base.repo /etc/yum.repos.d/')
        run_command('mv /root/Nfs-Media.repo /etc/yum.repos.d/')
        run_command('echo 迁移完成！')
