import logging
import os
import traceback

from paramiko.ssh_exception import SSHException

from migrate_check_ext import get_centos_version
from utils.util import MigrateRemoteExec

logger = logging.getLogger()

grub_cfg_7 = '''
menuentry 'NFSServer Linux 4.19.113-18.106.nfs4.x86_64' --class centos --class gnu-linux --class gnu --class os --unrestricted $menuentry_id_option 'gnulinux-4.19.113-18.106.nfs4.x86_64-advanced-0a644e53-e745-43a3-8639-f9cb5e57c9e4' {
 load_video
 set gfxpayload=keep
 insmod gzio
 insmod part_msdos
 insmod xfs
 set root='hd0,msdos1'
 if [ x$feature_platform_search_hint = xy ]; then
   search --no-floppy --fs-uuid --set=root --hint-bios=hd0,msdos1 --hint-efi=hd0,msdos1 --hint-baremetal=ahci0,msdos1 --hint='hd0,msdos1'  0b5b2483-9c52-4d65-9284-3227ee6d1c04
 else
   search --no-floppy --fs-uuid --set=root %s
 fi
 linux16 /vmlinuz-4.19.113-18.106.nfs4.x86_64 root=%s ro crashkernel=auto rd.lvm.lv=centos/root rd.lvm.lv=centos/swap rhgb quiet security=selinux enforcing=0 ima_appraise=off
 initrd16 /initramfs-4.19.113-18.106.nfs4.x86_64.img
}
'''
grub_cfg_8 = '''
#!/bin/sh
exec tail -n +3 $0
# This file provides an easy way to add custom menu entries.  Simply type the
# menu entries you want to add after this comment.  Be careful not to change
# the 'exec tail' line above.

menuentry 'NFSServer Linux 4.19.113-18.106.nfs4.x86_64' --class centos --class gnu-linux --class gnu --class os --unrestricted $menuentry_id_option 'gnulinux-4.19.113-18.106.nfs4.x86_64-advanced-0a644e53-e745-43a3-8639-f9cb5e57c9e4' {
 load_video
 set gfxpayload=keep
 insmod gzio
 insmod part_msdos
 insmod xfs
 set root='hd0,msdos1'
 if [ x$feature_platform_search_hint = xy ]; then
   search --no-floppy --fs-uuid --set=root --hint-bios=hd0,msdos1 --hint-efi=hd0,msdos1 --hint-baremetal=ahci0,msdos1 --hint='hd0,msdos1'  %s
 else
   search --no-floppy --fs-uuid --set=root %s
 fi
 linux /vmlinuz-4.19.113-18.106.nfs4.x86_64 root=/dev/mapper/cl-root ro crashkernel=auto rd.lvm.lv=cl/root rd.lvm.lv=cl/swap rhgb quiet security=selinux enforcing=0 ima_appraise=off
 initrd /initramfs-4.19.113-18.106.nfs4.x86_64.img
}
'''


def main8(ssh, path_gz):
    path_dir = os.path.dirname(path_gz)
    ssh.exec_pty(f'cd {path_dir} && tar -xvf {path_gz}')  # 解压
    ssh.exec(f"sed -i '8c DATA_DIR={path_dir}/nfs' {path_dir}/migration.sh")  # 修改migration.sh中DATA_DIR=xxx
    out = ssh.exec_pty(f'bash {path_dir}/migration.sh')  # 执行migration.sh
    if '设备上没有空间' in out:
        raise Exception('设备上没有空间')
    _uuid = ssh.exec("cat /boot/grub2/grub.cfg | grep set=root | grep -v hint-bios | awk '{print $NF}' | sed -n '1p'")
    cfg = grub_cfg_8 % (_uuid, _uuid)
    ssh.file_a('/etc/grub.d/40_custom', cfg, 'w')  # 修改/boot/grub2/grub.cfg,添加xxx
    ssh.exec("grub2-set-default 'NFSServer Linux 4.19.113-18.106.nfs4.x86_64'")  # 设置默认启动项
    ssh.exec("grub2-mkconfig -o /boot/grub2/grub.cfg")
    ssh.exec("rm -rf /.newroot/var/nfs/license.db")
    ssh.exec("echo 迁移完成！")
    # ssh.exec("reboot")  # 重启
    # comp_run -r /oldroot -c bash
    # root nfschina123!


def main7(ssh, path_gz):
    path_dir = os.path.dirname(path_gz)
    ssh.exec_pty(f'cd {path_dir} && tar -xvf {path_gz}')  # 解压
    ssh.exec(f"sed -i '8c DATA_DIR={path_dir}/nfs' {path_dir}/migration.sh")  # 修改migration.sh中DATA_DIR=xxx
    out = ssh.exec_pty(f'bash {path_dir}/migration.sh')  # 执行migration.sh
    if '设备上没有空间' in out:
        raise Exception('设备上没有空间')
    _uuid = ssh.exec("cat /boot/grub2/grub.cfg | grep set=root | grep -v hint-bios | awk '{print $NF}' | sed -n '1p'")
    _root = ssh.exec(
        "cat /boot/grub2/grub.cfg | grep linux16 | sed -n '1p' | awk -F ' ro ' '{print $1}' | awk -F ' root=' '{print $NF}'")
    cfg = grub_cfg_7 % (_uuid, _root)
    nu = ssh.exec("grep -wn '### BEGIN /etc/grub.d/10_linux ###' /boot/grub2/grub.cfg | awk -F ':' '{print $1}'")
    txt_head = ssh.exec(f'head -n {nu} /boot/grub2/grub.cfg')
    txt_tail = ssh.exec(f'tail -n +{int(nu) + 1} /boot/grub2/grub.cfg')
    ssh.file_a('/boot/grub2/grub.cfg', txt_head + cfg + txt_tail, 'w')  # 修改/boot/grub2/grub.cfg,添加xxx
    ssh.exec("grub2-set-default 'NFSServer Linux 4.19.113-18.106.nfs4.x86_64'")  # 设置默认启动项
    ssh.exec("rm -rf /.newroot/var/nfs/license.db")
    ssh.exec("echo 迁移完成！")
    # ssh.exec("reboot")  # 重启
    # comp_run -r /oldroot -c bash
    # root nfschina123!


def action_migrate(remote, path_gz, taskagent=None):
    """
    迁移agent
    """
    ip, port, username, password = remote
    is_success, msg = True, '成功'
    with MigrateRemoteExec(ip=ip, port=port, username=username, password=password) as ssh:
        try:
            centos_version = get_centos_version(remote)
            if centos_version in ['8.0', '8.1', '8.2', '8.3', '8.4', '8.5']:
                logger.info('迁移命令执行')
                main8(ssh, path_gz)
                logger.info('迁移命令成功')
            elif centos_version in ['7.3']:
                logger.info('迁移命令执行')
                main8(ssh, path_gz)
                logger.info('迁移命令成功')
            elif centos_version in ['7.0', '7.1', '7.2', '7.4', '7.5', '7.6', '7.7', '7.8', '7.9']:
                logger.info('迁移命令执行')
                main7(ssh, path_gz)
                logger.info('迁移命令成功')
            else:
                logger.error('不支持迁移方案B')
        except SSHException:
            pass
        except Exception as e:
            traceback.print_exc()
            exc_str = traceback.format_exc()
            logger.error(exc_str)
            is_success, msg = False, str(e)
    return is_success, msg, taskagent

# remote = ("60.10.10.137", 1007, "root", "root")
# path_gz = '/root/os_migrate.tar.gz'
# print(action_migrate(remote, path_gz))
