from rest_framework import serializers

from system.models import User, Menu, Role, Attachment, Lookup, Department
from utils.serializer import BaseModelSerializer


class DepartmentSerializer(BaseModelSerializer):
    class Meta:
        model = Department
        fields = '__all__'


class UserSerializer(BaseModelSerializer):
    last_login = serializers.CharField(read_only=True)
    last_operation = serializers.CharField(read_only=True)
    department_name = serializers.CharField(source='department.name', read_only=True)

    class Meta:
        model = User
        fields = (
            'id', 'username', 'nickname', 'phone', 'email', 'department', 'department_name', 'avatar', 'roles',
            'is_superuser', 'is_active', 'last_login', 'last_operation', 'route')


class UserListSerializer(UserSerializer):
    department_name = serializers.CharField(source='department.name', read_only=True)

    class Meta:
        model = User
        fields = (
            'id', 'username', 'nickname', 'phone', 'department', 'department_name', 'is_superuser', 'is_active',
            'create_time', 'route')


class RoleSerializer(BaseModelSerializer):
    class Meta:
        model = Role
        fields = '__all__'


class MenuSerializer(BaseModelSerializer):
    class Meta:
        model = Menu
        fields = '__all__'


class AttachmentSerializer(BaseModelSerializer):
    file = serializers.FileField(use_url=False)
    username = serializers.FileField(read_only=True)

    def create(self, validated_data):
        validated_data['username'] = self.context['request'].user.username
        return super().create(validated_data)

    class Meta:
        model = Attachment
        fields = '__all__'


class LookupSerializer(BaseModelSerializer):
    class Meta:
        model = Lookup
        fields = '__all__'
