import json
import logging
import traceback
from concurrent.futures.thread import ThreadPoolExecutor

from migrate_a import action_migrate as action_migrate_a
from migrate_b import action_migrate as action_migrate_b
from migrate_check_ext import get_info, get_local, get_config

pool = ThreadPoolExecutor(max_workers=500)

logger = logging.getLogger()


def update_status(taskagent, taskagent_status, msg):
    taskagent.status = taskagent_status
    taskagent.msg = msg
    taskagent.save(update_fields=["status", "msg", "update_time"])
    task = taskagent.task
    if all([int(i.status) in [10, 100, 20, 200, 30, 300, 40, 400, 50, 500, 60, 600, 70, 700, 80, 800] for i in task.taskagents.all()]):
        task.status = str(taskagent_status).replace('0', '')
        task.save(update_fields=["status", "update_time"])


def run_migrate_a(taskagent):
    """
    执行迁移方案A
    """
    update_status(taskagent, 5, '')
    agent = taskagent.agent
    remote = (agent.ip, agent.port, agent.username, agent.password)
    repo_content = taskagent.task.repo.content
    logger.info(f'迁移方案A 执行：{taskagent.id} {remote}')
    future = pool.submit(action_migrate_a, remote, repo_content, taskagent)
    future.add_done_callback(callback_migrate_a_result)


def callback_migrate_a_result(future):
    """
    迁移任务完成回调
    """
    try:
        is_success, msg, taskagent = future.result()
        agent = taskagent.agent
        remote = (agent.ip, agent.port, agent.username, agent.password)

        task_agent_data = taskagent.taskagentdata
        task_agent_data.info_new = json.dumps(get_info(remote))
        task_agent_data.rpm_new = json.dumps(get_local(remote))
        task_agent_data.config_new = json.dumps(get_config(remote))
        task_agent_data.save()

        update_status(taskagent, 50 if is_success else 500, msg)
        logger.info(f'迁移方案A 完成：{taskagent.id} {remote}')
    except Exception as e:
        traceback.print_exc()
        exc_str = traceback.format_exc()
        logger.error(exc_str)


def run_migrate_b(taskagent):
    """
    执行迁移方案B
    """
    update_status(taskagent, 8, '')
    agent = taskagent.agent
    remote = (agent.ip, agent.port, agent.username, agent.password)
    path_gz = taskagent.task.path_gz
    logger.info(f'迁移方案B 执行：{taskagent.id} {remote}')
    future = pool.submit(action_migrate_b, remote, path_gz, taskagent)
    future.add_done_callback(callback_migrate_b_result)


def callback_migrate_b_result(future):
    """
    迁移任务完成回调
    """
    is_success, msg, taskagent = future.result()
    agent = taskagent.agent
    remote = (agent.ip, agent.port, agent.username, agent.password)
    update_status(taskagent, 80 if is_success else 800, msg)
    logger.info(f'迁移方案B 完成：{taskagent.id} {remote}')
