import logging
import traceback

from rest_framework.exceptions import MethodNotAllowed, PermissionDenied, AuthenticationFailed, ValidationError
from rest_framework_simplejwt.exceptions import InvalidToken

from utils.response import ErrorServResponse, ErrorResponse

logger = logging.getLogger()


class CustomServException(Exception):
    """
    该类是自定义服务端异常类，对于一些不符合开发规范的，未按照约定的情况，包500
    """
    pass


class CustomException(Exception):
    """
    该类是自定义异常类，对于一些自定义报错，可以灵活使用
    **kwargs参数是对标ErrorResponse(**exc.kwargs)
    所以参数是ErrorResponse的参数
    data=None, msg='失败', code=400, status=None, template_name=None, headers=None, exception=False, content_type=None
    """

    def __init__(self, **kwargs):
        self.kwargs = kwargs


def custom_exception_handler(exc, context):
    try:
        if type(exc) == CustomException:
            logger.warning(traceback.format_exc())
            return ErrorResponse(**exc.kwargs)
        status = None
        if type(exc) == MethodNotAllowed:
            msg = str(exc.detail)
            logger.warning(traceback.format_exc())
        if type(exc) == PermissionDenied:  # RoutePermission权限验证
            msg = str(exc.detail)
            logger.warning(traceback.format_exc())
        if type(exc) == AuthenticationFailed:  # 用户名密码不正确时
            msg = "用户名或密码不正确"
            logger.warning(traceback.format_exc())
        if type(exc) == ValidationError:
            msg = "\n".join([k + ": " + "\n".join(v) for k, v in exc.detail.items()])
            logger.warning(traceback.format_exc())
        if type(exc) == InvalidToken:
            msg = exc.default_detail
            status = 401
            logger.warning(traceback.format_exc())
        if type(exc) == Exception:
            msg = str(exc)
            logger.warning(traceback.format_exc())
        return ErrorResponse(msg=msg, status=status)
    except:
        pass
    logger.error(traceback.format_exc())
    return ErrorServResponse()
