from django.db import models

from utils.util import get_uuid


class FixCharField(models.Field):

    def __init__(self, max_length, *args, **kwargs):
        self.max_length = max_length
        super().__init__(max_length=max_length, *args, **kwargs)

    def db_type(self, connection):
        return 'char(%s)' % self.max_length


class DateTimeFormatField(models.DateTimeField):
    def __init__(self, verbose_name=None, name=None, auto_now=False, auto_now_add=False, precision=0, **kwargs):
        self.precision = precision
        super().__init__(verbose_name, name, auto_now, auto_now_add, **kwargs)

    def db_type(self, connection):
        return 'datetime(%d)' % self.precision


class MultipleChoiceField(models.JSONField):
    def __init__(self, scope=None, verbose_name=None, name=None, encoder=None, decoder=None, **kwargs):
        self.scope = scope  # 包含的项目
        super().__init__(verbose_name, name, encoder, decoder, **kwargs)

    def deconstruct(self):
        name, path, args, kwargs = super().deconstruct()
        kwargs["scope"] = self.scope
        return name, path, args, kwargs


class SingleChoiceField(models.CharField):
    def __init__(self, *args, db_collation=None, scope=None, **kwargs):
        self.scope = scope  # 包含的项目
        super().__init__(*args, db_collation=db_collation, **kwargs)

    def deconstruct(self):
        name, path, args, kwargs = super().deconstruct()
        kwargs["scope"] = self.scope
        return name, path, args, kwargs


class BaseModel(models.Model):
    objects = models.Manager()
    id = FixCharField(primary_key=True, max_length=32, default=get_uuid)
    create_time = DateTimeFormatField(auto_now_add=True)
    update_time = DateTimeFormatField(auto_now=True)

    class Meta:
        abstract = True  # 表示该类是一个抽象类，只用来继承
