from django.utils import timezone
from rest_framework import permissions
from rest_framework.permissions import IsAuthenticated


class IsAuthPermission(IsAuthenticated):
    """
    验证接口是否登录
    """

    def has_permission(self, request, view):
        is_has_perm = bool(request.user and request.user.is_authenticated)
        if is_has_perm:
            request.user.last_operation = timezone.now()
            request.user.save(update_fields=["last_operation"])  # 保存最后操作时间
        return is_has_perm


class RoutePermission(permissions.BasePermission):
    """
    验证user上是否有route权限
    """

    def has_permission(self, request, view):
        if request.user.is_superuser:
            return True
        if hasattr(view, 'route_method_allow') and view.action in view.route_method_allow.keys():
            # 判断请求是否是route_method_allow其中的方法
            return True
        if not request.user.route:
            return False
        for name, allow_method in request.user.route.items():
            if name == view.__class__.__name__ and view.action in allow_method:
                # 判断请求是否是allow_method其中的方法
                return True
        return False
