from rest_framework import serializers

from system.models import get_value_by_category
from utils.model import MultipleChoiceField, SingleChoiceField


class BaseModelSerializer(serializers.ModelSerializer):
    id = serializers.CharField(read_only=True)

    def validate(self, attrs):
        class_model = self.Meta.model
        for field in class_model._meta.fields:
            if field.attname in attrs.keys() and type(field) == MultipleChoiceField:
                value = attrs[field.attname]
                if type(value) != list:
                    raise Exception(f'{field.attname}字段值必须是list')
                if field.scope is None:
                    continue
                scope = field.scope
                if type(field.scope) == str:
                    scope = get_value_by_category(field.scope)
                if not set(value).issubset(scope):  # field.scope是否包含value
                    raise Exception(f'{field.attname}字段值{value}不在{field.scope}范围内')
            if field.attname in attrs.keys() and type(field) == SingleChoiceField:
                value = attrs[field.attname]
                if field.scope is None:
                    continue
                scope = field.scope
                if type(field.scope) == str:
                    scope = get_value_by_category(field.scope)
                if value not in scope:  # field.scope是否包含value
                    raise Exception(f'{field.attname}字段值{value}不在{field.scope}范围内')
        return attrs
